import React, { useRef, useState, useEffect } from 'react';
import { Row, Col, Space } from 'antd';
import { Form, Input, Radio, Button, Tooltip } from '@arco-design/web-react';
import { register } from '@/assets/images'
import { question1, } from '@/assets/images';
import ArcoUpload from '@/components/ArcoUpload';
import * as $$ from '@/utils/utility';
import { Scrollbars } from "react-custom-scrollbars";
import { getOffset, getSize } from '@/utils/utility';

const FormItem = Form.Item;
const appUrl = $$.appUrl;
const RadioGroup = Radio.Group;
const TextArea = Input.TextArea;

function delFile(id) {
  return $$.ax.request({ url: `fileInfo/deleteFileById`, type: 'get', service: 'sys', data: { id } });
}

function getData(data) {
  return $$.ax.request({ url: `caseAssistApply/getByCaseId`, type: 'get', service: 'mediate', data });
}

function submit(data) {
  return $$.ax.request({ url: `caseAssistApply/reviewCaseAssistApply`, type: 'post', service: 'mediate', data });
}

const AuditView = (props) => {
  const formRef = useRef();
  const scrollRef = useRef(null);
  const [id, setId] = useState();
  const [infoData, setInfoData] = useState({});
  const [height, setHeight] = useState(500);

  useEffect(() => {
    getInfoData()
    onWindowResize()
    window.addEventListener("resize", onWindowResize);
    // 返回一个函数，该函数会在组件卸载前执行  
    return () => {
      // 组件销毁时执行  
      window.removeEventListener("resize", onWindowResize);
    };
  }, [])

  const onWindowResize = () => {
    let offsetTop = 0;
    if (scrollRef.current.container) {
      offsetTop = getOffset(scrollRef.current.container).top;
    }
    setHeight(getSize().windowH - offsetTop - 74)
  };

  //回显数据
  const getInfoData = async () => {
    const res = await getData({
      caseId: props.caseId
    })
    if (res.type) {
      setInfoData(res.data || {})
      setId(res.data.id)
    }
  }

  //删除文件
  const handleDelFile = async (id) => {
    const res = await delFile(id)
    if (res.type) {
      $$.infoSuccess({ content: '删除成功！' });
    }
  }

  const handleSubmit = () => {
    if (formRef.current) {
      formRef.current.validate(undefined, (errors, values) => {
        if (!errors) {
          const { file, ...rest } = formRef.current.getFields()
          requestSubmit({
            ...rest,
            id: id
          })
        }
      })
    }
  }

  const requestSubmit = async (data) => {
    const res = await submit(data)
    if (res.type) {
      $$.infoSuccess({ content: '提交成功！' });
    }
  }

  return (
    <div className='dataSync'>
      <div className='dataSync-noBackTabPage'>
        <div className="whiteBox">
          <Col span={24} className='title'>
            <Space size='small'>
              <div className='MediationInfo-subTitle' style={{ marginTop: '-9px' }}></div><h5>联合处置申请</h5>
            </Space>
          </Col>
          <Row gutter={[16, 16]}>
            <Col span={24}>
              <div><div className="title-text">添加配合部门</div></div>
              <div>{infoData.applyAssistUnitName || '-'}</div>
            </Col>
            <Col span={24}>
              <div><div className="title-text">添加理由</div></div>
              <div>{infoData.applyContent || '-'}</div>
            </Col>
            <Col span={24}>
              <div className="title"><div className="title-text">申请时间</div></div>
              <div>{$$.myTimeFormat(infoData.applyTime, 'YYYY-MM-DD HH:mm') || '-'}</div>
            </Col>
            <Col span={24}>
              <div><div className="title-text">申请人</div></div>
              <div>
                {infoData.applyUnitName}&nbsp;&nbsp;
                {infoData.applyUserName || '-'}
                <img src={register} alt="" className="title-register" />
              </div>
            </Col>
          </Row>

        </div>
        <div className='whiteBox' style={{ marginTop: '8px' }}>
          <Scrollbars style={{ height: height + 'px' }} autoHide ref={scrollRef}>
            <Space size='small'>
              <div className='MediationInfo-subTitle' style={{ marginTop: '-8px' }}></div><h5>审核</h5>
            </Space>
            <Form
              ref={formRef}
              layout='vertical'
              requiredSymbol={false}
              initialValues={{
              }}//默认值
              scrollToFirstError
            >
              <Row>
                <Col span={24}>
                  <FormItem
                    label={(<div style={{ display: 'flex' }}>审核结果</div>)}
                    field='auditResult'
                  >
                    <RadioGroup
                      direction='vertical'
                      options={$$.options.auditResult}
                      onChange={(value) => {
                        if (value) {
                          const data = $$.options.auditResult.find(item => item.value === value)
                          formRef.current.setFieldValue('auditResultName', data.label)
                        } else {
                          formRef.current.setFieldValue('auditResultName', '')
                        }
                      }}
                    />
                  </FormItem>
                </Col>
                <Col span={24}>
                  <FormItem
                    label={(<div style={{ display: 'flex' }}>理由说明<div className="must">必填</div></div>)}
                    field='auditContent'
                    rules={[{ required: true, message: '请选择理由说明' }]}
                  >
                    <TextArea
                      autoSize={{ minRows: 4, maxRows: 8 }}
                      placeholder='请填写不同意联合处置申请的理由'
                    />
                  </FormItem>
                </Col>
                <Col span={24} className="doubleFile">
                  <ArcoUpload
                    params={{
                      action: `${appUrl.fileUrl}/${appUrl.sys}/api/web/fileInfo/upload?mainId=${props.caseId}&ownerId=${id}&ownerType=22_00018-509`,
                    }}
                    field='file'
                    label='附件材料'
                    handleDelFile={handleDelFile}
                  />
                </Col>
              </Row>
            </Form>
          </Scrollbars>
          <div className='dialogFooter'>
            <Button
              type="primary"
              className="dialogPrimary"
              onClick={handleSubmit}
            >
              提交
            </Button>
          </div>
        </div>
      </div>
    </div>
  )
}

export default AuditView;